=======
Credits
=======

Development Lead
----------------

* Juan David Alzate Cardona <jdalzatec@unal.edu.co>

Contributors
------------

* Juan David Alzate Cardona <jdalzatec@unal.edu.co>
* Daniel Felipe Rodríguez Patiño <dfrodriguezp@unal.edu.co>
* Juan Sebastian Salcedo Gallo <jussalcedoga@unal.edu.co>
* Luisa Fernanda Velásquez González <lufvelasquezgo@unal.edu.co>
